@@ -19,20 +19,16 @@
 package org.jpmml.converter;
 
 import java.util.List;
-import java.util.Objects;
 
 import org.dmg.pmml.DataType;
 import org.dmg.pmml.Field;
 import org.dmg.pmml.HasDiscreteDomain;
-import org.jpmml.model.ToStringHelper;
-
-public class CategoricalLabel extends ScalarLabel {
-
-	private List<?> values = null;
+import org.dmg.pmml.OpType;
 
+public class CategoricalLabel extends DiscreteLabel {
 
 	public <F extends Field<F> & HasDiscreteDomain<F>> CategoricalLabel(F field){
-		this(field.requireName(), field.requireDataType(), PMMLUtil.getValues(field));
+		this(field.requireName(), field.requireDataType(), FieldUtil.getValues(field));
 	}
 
 	public CategoricalLabel(CategoricalFeature categoricalFeature){
@@ -40,13 +36,16 @@ public class CategoricalLabel extends ScalarLabel {
 	}
 
 	public CategoricalLabel(DataType dataType, List<?> values){
-		this(null, dataType, values);
+		super(dataType, values);
 	}
 
 	public CategoricalLabel(String name, DataType dataType, List<?> values){
-		super(name, dataType);
+		super(name, dataType, values);
+	}
 
-		setValues(values);
+	@Override
+	public OpType getOpType(){
+		return OpType.CATEGORICAL;
 	}
 
 	@Override
@@ -59,9 +58,19 @@ public class CategoricalLabel extends ScalarLabel {
 		return (CategoricalLabel)super.toAnonymousLabel();
 	}
 
+	@Override
+	public CategoricalLabel toCategoricalLabel(){
+		return this;
+	}
+
+	@Override
+	public OrdinalLabel toOrdinalLabel(){
+		return new OrdinalLabel(getName(), getDataType(), getValues());
+	}
+
 	@Override
 	public int hashCode(){
-		return (31 * super.hashCode()) + Objects.hashCode(this.getValues());
+		return super.hashCode();
 	}
 
 	@Override
@@ -70,41 +79,9 @@ public class CategoricalLabel extends ScalarLabel {
 		if(object instanceof CategoricalLabel){
 			CategoricalLabel that = (CategoricalLabel)object;
 
-			return super.equals(object) && Objects.equals(this.getValues(), that.getValues());
+			return super.equals(object);
 		}
 
 		return false;
 	}
-
-	@Override
-	protected ToStringHelper toStringHelper(){
-		return super.toStringHelper()
-			.add("values", getValues());
-	}
-
-	public int size(){
-		List<?> values = getValues();
-
-		return values.size();
-	}
-
-	public Object getValue(int index){
-		List<?> values = getValues();
-
-		return values.get(index);
-	}
-
-	public List<?> getValues(){
-		return this.values;
-	}
-
-	private void setValues(List<?> values){
-		values = Objects.requireNonNull(values);
-
-		if(values.isEmpty()){
-			throw new IllegalArgumentException();
-		}
-
-		this.values = values;
-	}
 }
\ No newline at end of file
