@@ -31,12 +31,14 @@ public class ModelCleanerBattery extends VisitorBattery {
 
 		// OutputField elements
 		add(DerivedOutputFieldTransformer.class);
-		add(OutputCleaner.class);
 
 		// Most "aggressive", should be applied last,
 		// when all surviving fields are on their final locations
 		add(MiningSchemaCleaner.class);
 
 		add(ModelVerificationCleaner.class);
+
+		// Field container elements
+		add(ModelCleaner.class);
 	}
 }
\ No newline at end of file
