@@ -24,11 +24,11 @@ import java.util.stream.Collectors;
 
 import org.dmg.pmml.DataField;
 import org.dmg.pmml.DataType;
-import org.dmg.pmml.FieldName;
 import org.dmg.pmml.MiningFunction;
 import org.dmg.pmml.OpType;
 import org.dmg.pmml.Predicate;
 import org.dmg.pmml.ScoreDistribution;
+import org.dmg.pmml.ScoreProbability;
 import org.dmg.pmml.SimplePredicate;
 import org.dmg.pmml.True;
 import org.dmg.pmml.mining.MiningModel;
@@ -43,12 +43,13 @@ import org.jpmml.converter.CategoricalLabel;
 import org.jpmml.converter.CategoryManager;
 import org.jpmml.converter.ContinuousFeature;
 import org.jpmml.converter.Feature;
+import org.jpmml.converter.FeatureImportanceMap;
 import org.jpmml.converter.ModelUtil;
 import org.jpmml.converter.Schema;
 import org.jpmml.converter.ValueUtil;
 import org.jpmml.converter.mining.MiningModelUtil;
 
-public class RangerConverter extends TreeModelConverter<RGenericVector> {
+public class RangerConverter extends TreeModelConverter<RGenericVector> implements HasFeatureImportances {
 
 	boolean hasDependentVar = false;
 
@@ -70,7 +71,7 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 		RGenericVector variableLevels = DecorationUtil.getGenericElement(ranger, "variable.levels");
 
 		{
-			FieldName name = FieldName.create("_target");
+			String name = "_target";
 
 			DataField dataField;
 
@@ -108,7 +109,7 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 
 			String independentVariableName = independentVariableNames.getValue(i);
 
-			FieldName name = FieldName.create(independentVariableName);
+			String name = independentVariableName;
 
 			DataField dataField;
 
@@ -130,23 +131,44 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 	public MiningModel encodeModel(Schema schema){
 		RGenericVector ranger = getObject();
 
-		RStringVector treetype = ranger.getStringElement("treetype");
+		RStringVector treeType = ranger.getStringElement("treetype");
+		RGenericVector forest = ranger.getGenericElement("forest");
 
-		switch(treetype.asScalar()){
+		switch(treeType.asScalar()){
 			case "Regression":
-				return encodeRegression(ranger, schema);
+				return encodeRegression(forest, schema);
 			case "Classification":
-				return encodeClassification(ranger, schema);
+				return encodeClassification(forest, schema);
 			case "Probability estimation":
-				return encodeProbabilityForest(ranger, schema);
+				return encodeProbabilityForest(forest, schema);
 			default:
 				throw new IllegalArgumentException();
 		}
 	}
 
-	private MiningModel encodeRegression(RGenericVector ranger, Schema schema){
-		RGenericVector forest = ranger.getGenericElement("forest");
+	@Override
+	public FeatureImportanceMap getFeatureImportances(Schema schema){
+		RGenericVector ranger = getObject();
 
+		RStringVector importanceMode = ranger.getStringElement("importance.mode", false);
+		RDoubleVector variableImportance = ranger.getDoubleElement("variable.importance", false);
+
+		if(variableImportance == null){
+			return null;
+		}
+
+		List<? extends Feature> features = schema.getFeatures();
+
+		FeatureImportanceMap result = new FeatureImportanceMap(importanceMode != null ? importanceMode.asScalar() : null);
+
+		for(int i = 0; i < features.size(); i++){
+			result.put(features.get(i), variableImportance.getValue(i));
+		}
+
+		return result;
+	}
+
+	private MiningModel encodeRegression(RGenericVector forest, Schema schema){
 		ScoreEncoder scoreEncoder = new ScoreEncoder(){
 
 			@Override
@@ -160,14 +182,12 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 		List<TreeModel> treeModels = encodeForest(forest, MiningFunction.REGRESSION, scoreEncoder, schema);
 
 		MiningModel miningModel = new MiningModel(MiningFunction.REGRESSION, ModelUtil.createMiningSchema(schema.getLabel()))
-			.setSegmentation(MiningModelUtil.createSegmentation(Segmentation.MultipleModelMethod.AVERAGE, treeModels));
+			.setSegmentation(MiningModelUtil.createSegmentation(Segmentation.MultipleModelMethod.AVERAGE, Segmentation.MissingPredictionTreatment.RETURN_MISSING, treeModels));
 
 		return miningModel;
 	}
 
-	private MiningModel encodeClassification(RGenericVector ranger, Schema schema){
-		RGenericVector forest = ranger.getGenericElement("forest");
-
+	private MiningModel encodeClassification(RGenericVector forest, Schema schema){
 		RStringVector levels = forest.getStringElement("levels");
 
 		ScoreEncoder scoreEncoder = new ScoreEncoder(){
@@ -189,14 +209,12 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 		List<TreeModel> treeModels = encodeForest(forest, MiningFunction.CLASSIFICATION, scoreEncoder, schema);
 
 		MiningModel miningModel = new MiningModel(MiningFunction.CLASSIFICATION, ModelUtil.createMiningSchema(schema.getLabel()))
-			.setSegmentation(MiningModelUtil.createSegmentation(Segmentation.MultipleModelMethod.MAJORITY_VOTE, treeModels));
+			.setSegmentation(MiningModelUtil.createSegmentation(Segmentation.MultipleModelMethod.MAJORITY_VOTE, Segmentation.MissingPredictionTreatment.RETURN_MISSING, treeModels));
 
 		return miningModel;
 	}
 
-	private MiningModel encodeProbabilityForest(RGenericVector ranger, Schema schema){
-		RGenericVector forest = ranger.getGenericElement("forest");
-
+	private MiningModel encodeProbabilityForest(RGenericVector forest, Schema schema){
 		RStringVector levels = forest.getStringElement("levels");
 
 		CategoricalLabel categoricalLabel = (CategoricalLabel)schema.getLabel();
@@ -206,10 +224,12 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 			@Override
 			public Node encode(Node node, Number splitValue, RNumberVector<?> terminalClassCount){
 
-				if(splitValue.doubleValue() != 0d || (terminalClassCount == null || terminalClassCount.size() != levels.size())){
+				if(splitValue.doubleValue() != 0d || (terminalClassCount == null)){
 					throw new IllegalArgumentException();
 				}
 
+				RVectorUtil.checkSize(levels, terminalClassCount);
+
 				node = new ClassifierNode(node);
 
 				List<ScoreDistribution> scoreDistributions = node.getScoreDistributions();
@@ -226,7 +246,7 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 						maxProbability = probability;
 					}
 
-					ScoreDistribution scoreDistribution = new ScoreDistribution(value, probability);
+					ScoreDistribution scoreDistribution = new ScoreProbability(value, null, probability);
 
 					scoreDistributions.add(scoreDistribution);
 				}
@@ -238,7 +258,7 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 		List<TreeModel> treeModels = encodeForest(forest, MiningFunction.CLASSIFICATION, scoreEncoder, schema);
 
 		MiningModel miningModel = new MiningModel(MiningFunction.CLASSIFICATION, ModelUtil.createMiningSchema(categoricalLabel))
-			.setSegmentation(MiningModelUtil.createSegmentation(Segmentation.MultipleModelMethod.AVERAGE, treeModels))
+			.setSegmentation(MiningModelUtil.createSegmentation(Segmentation.MultipleModelMethod.AVERAGE, Segmentation.MissingPredictionTreatment.RETURN_MISSING, treeModels))
 			.setOutput(ModelUtil.createProbabilityOutput(DataType.DOUBLE, categoricalLabel));
 
 		return miningModel;
@@ -304,7 +324,7 @@ public class RangerConverter extends TreeModelConverter<RGenericVector> {
 
 			int splitLevelIndex = ValueUtil.asInt(Math.floor(splitValue.doubleValue()));
 
-			FieldName name = categoricalFeature.getName();
+			String name = categoricalFeature.getName();
 			List<?> values = categoricalFeature.getValues();
 
 			java.util.function.Predicate<Object> valueFilter = categoryManager.getValueFilter(name);
